## So you want to do a PhD?

I very enthusiastically welcome applications to undertake PhD study in our department at the University of Birmingham. I should also note that applications by women, people of colour, and programmes of research pursuing subjects and following critical frames of reference which are relevant to non privileged contexts are particularly welcome (e.g. post-colonial, black theology, feminist, eco-womanist, liberation, queer theology, etc.).

The process of application varies quite a lot from country to country, in some cases quite dramatically, so I have written this brief guide so that anyone wanting to apply will have a fair sense of the criteria and expectations for application.

## Features of the UK PhD

First a few salient details about our context here (in the UK at large research-intensive Universities):

- A British PhD is generally expected to take 3 years, with an additional fourth or (in rare cases) fifth year to write-up a final draft of your work. In spite of how that sounds, this is a rather brief window of time, particularly in contrast to the USA where PhD students are expected to engage in further generalist preparatory coursework for 1-3 years before taking some sort of comprehensive examination which can validate that they have sufficient general knowledge of the discipline and research methods to conduct research at a doctoral level, leading to a programme of research that can take 5 years or more. Given that this is the case, students will be expected to have completed a strong masters degree *in the subject* they are applying to. If you do not have any previous degrees in religious studies or theology, regardless of how smart you seem to be, I will probably invite you to apply first to complete a 1 year Masters by Research degree under my supervision, ideally exploring some aspect of your preferred research topic or something directly adjacent to it. No matter how many other degrees you have and how well you've done in them (and I include doctorate degrees in other subject areas) this will likely be my suggestion. In some (admittedly rare) cases, progress completed under an MA can be folded into a PhD, so that the candidate generally still completes in 3 years, with two degrees in hand at the end. My experience has shown that there is no substitute for discipline specific background knowledge and research experience and it is a disservice to expect a PhD candidate to cram all that extra work into what is already an accelerated programme.
- Funding for doctoral studies here is rare, with often a maximum of a few partial tuition scholarships awarded in a department each year. Most PhD funding comes from external sources, and applications to these are usually driven by the PhD candidate themself. Unless your programme of work is very exceptional: being linked to specific forms of impact (e.g. changing something in the world out there, with meaningful partnerships and collaborations already in place), or commending dissemination at a high level (e.g. you have already published some forms of scholarly work) it is unlikely you will be able to secure funding for your PhD. You should expect to have some form of external funding secured which can support your work (e.g. savings, income support, or paid work). I am a very enthusiastic champion and will write references to support an infinite number of applications for funding should you be proactive enough to pursue it before and during your programme of research.
- Cohort size is much less limited here, so that in contrast to the USA, where many supervisors complain that their departments prevent them from supervising more than one or two students at a time, a supervisor can have more than a dozen students they are working with at any given time. Universities provide us with a workload allocation commensurate with the number of PhD candidates we're supervising, so there are some protections in place to ensure that each candidate gets due attention during their programme, but I have also found that there is a natural limit that varies from person to person. I generally will only take on a maximum of 6 candidates at any one time. This means that I may be reluctant to take on new PhDs in a particular year, but I'm very happy to keep up correspondence and work with students to refine their proposals in the intervening period.
- Given the short duration of the programme, PhD candidates undertaking work here are expected to work with a high level of independence. Even in the most colleagial and convivial departments, you will spend a great deal of time working alone, so this is something to bear in mind as you consider undertaking PhD study. 
- I meet with my PhD students on a monthly basis, 10 times a year (it is important to take breaks!). I generally expect that you will have written or revised a substantial piece of work for 4-5 of those meetings, and at least one of them will be conducted in the form of a group "laboratory" which will be a group supervision.
- Given all the limits noted above, I provide special effort to "level the playing field" for PhD candidates with anxiety, depression, other mental health struggles or who are neuro-divergent. I am happy to chat more about this if you have specific questions about how you can successfully complete a PhD if any of these are factors for you (short answer: you can!).
- You can matriculate for a PhD that is by "distance," e.g. you stay in your home country and we do supervision via videoconference on the same basis outlined above. I generally will expect you to have a good reason as to why remaining in your context will be an integral part of your research process and won't instead be a distraction.
- You can also matriculate for a PhD that is part time, e.g. 5 supervisions a year on a bi-monthly basis over the course of 6-8 years. Again, I will expect you to indicate the specific reason why remaining part time is important to your PhD. Needing to work to support yourself or yourself and family is a very good reason, but we'll need to talk about how your PhD study won't jeopardise your financial security. It's generally my preference to supervise full-time projects, so while I understand the benefits of a part time programme, I'll generally prefer full-time unless there is a specific and necessary reason for doing things otherwise.
- Generally, the first 6-9 months of your PhD will be some blend of exploratory and constructive inquiry. By the summer of your first year you will need to have written a long-form piece of writing (8k words or so) and an outline of your proposed PhD thesis which will be submitted for a progress panel conducted by my colleagues. If your work is deemed insufficient, this panel can downgrade your degree to an MA or result in the termination of your programme of study, so this is an important milestone. In the second year, I expect most candidates to work on framing up chapters for their thesis and working on professional development (presenting at conferences, doing book reviews, networking, etc.). In the third year, you will be working to complete a final polished draft of your thesis, ideally for submission towards a viva voce examination by the end of Y3. The University of Birmingham does not provide any workload allocation for supervision beyond the third year, so whilst I will expect us to correspond and be in regular contact for the fourth year (if you have one), I will not provide regular supervisions and will need to book out time for reading drafts carefully, potentially avoiding periods which involve intensive teaching.
- Finally it's worth emphasising that a PhD is a major undertaking and will truly take your full-time attention for three years. I know everyone has side-interests and various distractions, but it will be up to you to ensure that you have time available for regular meetings and are able to put in regular work reading, writing, and reflecting every week, most of the year.

If you stil think you want to apply, read on!

## Now about the process:

### Step 1. Do reconaissance

- Whilst your formal application is to the University and is processed by administrative staff, you should identify one or two specific full-time permanent members of academic staff (i.e. "scholars") you want to do PhD study with. You can find out information about us on our [department websites](https://www.birmingham.ac.uk/staff/profiles/tr/kidwell-jeremy.aspx) or [personal web pages](https://jeremykidwell.info).
- Once you have identified individuals who have conducted research in the specicic area you want to work in (e.g. Christian eco-theology, activist ethnography, phenomenology of time, theology & economics, to list a few of mine), you should **begin preparation** so that you can make contact with that person and open up a conversation about whether they would be well suited to supervise your research. This person will expect you to have done a bit of homework before reaching out to them, in the very least enough to know about their specialisations and perhaps having read a few things they've written on the subject. You don't need to cite our work back to us, but please don't make an approach until you're confident about that person being at least interested in your subject and experienced in supervising work on it on the basis of a few hours invested in reading their work. This is a person you will spend at least three years with, working quite closely together, so this is a very reasonable expectation.
- It is generally considered impolite to send an inquiry concurrently to several different members of staff in the same department without letting them know you are doing so. Do your homework first, identify that specific person, and have a conversation with them (or 2-3 of them at different universities).
- In some cases, I am happy to make suggestions as to whom else it might be relevant to approach as a prospective supervisor, especially if you have not had the benefit of the forms of privilege which make these social networks perspicuous. However, it is generally considered ungracious to ask us to do reconaissance for you, especially if you have already asked us to consider a research proposal which isn't relevant to our various forms of expertise. If in any doubt, don't hesitate to ask.

### Step 2. Formulate a research proposal

Given the accelerated nature of the British PhD, a prospective supervisor will expect you to have some sense of the kind of research you want to conduct, be able to communicate this interest coherently and also demonstrate some awareness of the existing sub-field of research.

You can demonstrate this primarily by writing a research proposal. Expectations on these vary, but in my case, I'd prefer to receive a document that is between 1-2 pages (single-spaced in 12 point times new roman font). 

Your research proposal should do the following:

1. Explain why you’ve chosen this particular topic (this can and should be couched in personal narrative)
2. Explain why this research might be significant or novel in light of relevant extant scholarly literature
3. Explain which streams of existing scholarship you might be interacting with (e.g. "these three scholars (citation 1, citation 2, citation 3) have suggested x, and I'd like to further test their claims...")

All of this gets towards explaining also how this project might be viable to undertake within the space of a 3-year full time doctoral programme

In order to write this, you will need to conduct some research. If you do not have access to a local University library or a public library, there is still quite a lot online, do some work scanning google scholar and google books to get started. If you genuinely believe that you are unable to access resources which would help you to complete a research proposal, let me know in your initial correspondence.

It's possible you've already written a paper as a part of your Masters degree which helped you to stumble on your topic. If this is the case, please do go on to reconstitute your thinking in the form of a research proposal, rather than simply sending your paper along. You are welcome to include writing samples along with the research proposal if you have longer-form work you'd like to reference or share with us as part of your application, but please do the work of distilling your research proposal before sending it along. I have spent time reading proposals that are 20-30 pages and I have rarely found that they communicate details about a programme of research that couldn't be summarised well in 2 pages.

You can demonstrate that you have done this kind of research work by including some of the following features in your proposal:

1. Summarising trends in existing literature, with citations to the specific studies you are drawing on in your summary (no vague hand waving please)
2. Briefly citing seminal works in the field, explaining how you plan to build on or refute specific premises therein.
3. Briefly citing or summarising contemporary work in your chosen sub-field. I take "contemporary" to mean research which has been conducted in the last 20 years and will expect you to mention at least 2-3 studies which have been written in the last 5 years.

Important note: in this research proposal you should locate yourself in some specific sub-field of ethics, theology, or religious studies, so not "Christian theology" or "sociology" but something more like "pentecostal Christian eco-theology" or "studies of religious environmental activists in Europe".

This proposal should not be perfect, but it should be polished. I'll notice if there are typographical errors.

No one will expect you to conduct the exact study that you propose in this document - it is intended to demonstrate that you can formulate and communicate a research project. However, it should have some anchoring in work you have done and might be expected to do in the future based on your skills, experience, and training to date. So not wildly aspirational, please. If you decide to matriculate for PhD study with me, in our first supervision we'll use your research proposal as a leaping-off point to plan out 3-6 months of exploratory inquiry and writing.

Please note: I know that the "research proposal" format is a peculiar white anglophone-culture device. So, it is important to note that I will set aside this expectation if you have personal reason not to follow convention. I might expect (and have welcomed) proposals in longer-form personal narrative, or in non-propositional forms, e.g. artistically or as dance. I also welcome more open-ended proposals which aim to pursue action research, auto-ethnography or participatory inquiry (though be aware that I am aware of the methodological literature on all of these modes of inquiry).


### Step 3. Make an initial inquiry

Having done some reconaissance, conducted some research and crytallised your intellectual desires into a research proposal, it's time to make contact.

You should do this via email, with a brief note of introduction, a summary of your topic in 2-3 sentences and some indications of why you think my background would make me a suitable supervisor for the topic you are pursuing. A bit of biographical detail is also nice in helping me to know about why you've decided to do PhD work. It is expected that your actual programme of research will potentially be quite different from what you propose in our initial conversations. It is likely that I will suggest revisions once we begin supervision. This email is meant to help me to connect with your interests, assess whether I'd be a viable supervisor for your work and whether your project could be a viable PhD programme.

I may make suggestions for revision and ask you to return a revised proposal (no more than two drafts, and more  likely just one, depending on how things come together). Once we've reached a final form for your proposal and I've had time to review it (bear in mind this can be a few weeks at some points in the academic year) and if things seem to fit, I'll invite you to do an interview by phone or videoconference so we can chat about the details of your proposal and also so that I can answer questions you might have. You are welcome to choose not to make revisions to your proposal. If I make suggesions, my intent here is to help you to refine your research in order to make it more viable, with the expectation that this might strengthen your application to any number of universities. It's worth noting that this process isn’t any guarantee of a particular result with regards to your application for admission to the programme, but rather is meant to serve as part of the broader process of application.

Based on the proposal and the interview, I'll make a reecommendation regarding your application which will go to our Head of Postgraduate studies for review.